==> haskell-ghcide-test-utils-1.9.0.0-273-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-AuF2JGTcXJcF1AgJ4XH6nW
key:                  ghcide-test-utils-1.9.0.0-AuF2JGTcXJcF1AgJ4XH6nW
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  5d29be83e8f2eec17c3d991186fcc588
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-AuF2JGTcXJcF1AgJ4XH6nW
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-test-0.15.0.1-KuiVyYsgFJwBYTaqsBcaZ8
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK
    tasty-hunit-0.10.2-2LR7aB9N8B7BXZbrMOVMFb text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-test-utils-1.9.0.0-275-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-EjElSopDQJ4Jf3t2cix90Z
key:                  ghcide-test-utils-1.9.0.0-EjElSopDQJ4Jf3t2cix90Z
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  5a66c9c5a9516f32bba1db45e174beab
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-EjElSopDQJ4Jf3t2cix90Z
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    lsp-test-0.15.0.1-G1KOIGMqj5U8dP5sBy33Es
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3
    tasty-hunit-0.10.2-96pg6B929I9E8nnywjEniv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
